==> aws-parallelcluster-3.0.0b1.tar.gz: aws-parallelcluster-3.0.0b1/src/pcluster/api/models/__init__.py <==
# Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
# with the License. A copy of the License is located at http://aws.amazon.com/apache2.0/
# or in the "LICENSE.txt" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
# OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions and
# limitations under the License.

# pylint: disable=R0801

# flake8: noqa


# import models into model package
from pcluster.api.models.ami_info import AmiInfo
from pcluster.api.models.bad_request_exception_response_content import BadRequestExceptionResponseContent
from pcluster.api.models.build_image_bad_request_exception_response_content import (
    BuildImageBadRequestExceptionResponseContent,
)
from pcluster.api.models.build_image_request_content import BuildImageRequestContent
from pcluster.api.models.build_image_response_content import BuildImageResponseContent
from pcluster.api.models.change import Change
from pcluster.api.models.cloud_formation_stack_status import CloudFormationStackStatus
from pcluster.api.models.cluster_configuration_structure import ClusterConfigurationStructure
from pcluster.api.models.cluster_info_summary import ClusterInfoSummary
from pcluster.api.models.cluster_instance import ClusterInstance
from pcluster.api.models.cluster_status import ClusterStatus
from pcluster.api.models.cluster_status_filtering_option import ClusterStatusFilteringOption
from pcluster.api.models.compute_fleet_status import ComputeFleetStatus
from pcluster.api.models.config_validation_message import ConfigValidationMessage
from pcluster.api.models.conflict_exception_response_content import ConflictExceptionResponseContent
from pcluster.api.models.create_cluster_bad_request_exception_response_content import (
    CreateClusterBadRequestExceptionResponseContent,
)
from pcluster.api.models.create_cluster_request_content import CreateClusterRequestContent
from pcluster.api.models.create_cluster_response_content import CreateClusterResponseContent
from pcluster.api.models.delete_cluster_response_content import DeleteClusterResponseContent
from pcluster.api.models.delete_image_response_content import DeleteImageResponseContent
from pcluster.api.models.describe_cluster_instances_response_content import DescribeClusterInstancesResponseContent
from pcluster.api.models.describe_cluster_response_content import DescribeClusterResponseContent
from pcluster.api.models.describe_compute_fleet_response_content import DescribeComputeFleetResponseContent
from pcluster.api.models.describe_image_response_content import DescribeImageResponseContent
from pcluster.api.models.describe_official_images_response_content import DescribeOfficialImagesResponseContent
from pcluster.api.models.dryrun_operation_exception_response_content import DryrunOperationExceptionResponseContent
from pcluster.api.models.ec2_ami_info import Ec2AmiInfo
from pcluster.api.models.ec2_ami_state import Ec2AmiState
from pcluster.api.models.ec2_instance import EC2Instance
from pcluster.api.models.get_cluster_log_events_response_content import GetClusterLogEventsResponseContent
from pcluster.api.models.get_cluster_stack_events_response_content import GetClusterStackEventsResponseContent
from pcluster.api.models.get_image_log_events_response_content import GetImageLogEventsResponseContent
from pcluster.api.models.get_image_stack_events_response_content import GetImageStackEventsResponseContent
from pcluster.api.models.image_build_status import ImageBuildStatus
from pcluster.api.models.image_builder_image_status import ImageBuilderImageStatus
from pcluster.api.models.image_configuration_structure import ImageConfigurationStructure
from pcluster.api.models.image_info_summary import ImageInfoSummary
from pcluster.api.models.image_status_filtering_option import ImageStatusFilteringOption
from pcluster.api.models.instance_state import InstanceState
from pcluster.api.models.internal_service_exception_response_content import InternalServiceExceptionResponseContent
from pcluster.api.models.limit_exceeded_exception_response_content import LimitExceededExceptionResponseContent
from pcluster.api.models.list_cluster_log_streams_response_content import ListClusterLogStreamsResponseContent
from pcluster.api.models.list_clusters_response_content import ListClustersResponseContent
from pcluster.api.models.list_image_log_streams_response_content import ListImageLogStreamsResponseContent
from pcluster.api.models.list_images_response_content import ListImagesResponseContent
from pcluster.api.models.log_event import LogEvent
from pcluster.api.models.log_stream import LogStream
from pcluster.api.models.node_type import NodeType
from pcluster.api.models.not_found_exception_response_content import NotFoundExceptionResponseContent
from pcluster.api.models.requested_compute_fleet_status import RequestedComputeFleetStatus
from pcluster.api.models.stack_event import StackEvent
from pcluster.api.models.tag import Tag
from pcluster.api.models.unauthorized_client_error_response_content import UnauthorizedClientErrorResponseContent
from pcluster.api.models.update_cluster_bad_request_exception_response_content import (
    UpdateClusterBadRequestExceptionResponseContent,
)
from pcluster.api.models.update_cluster_request_content import UpdateClusterRequestContent
from pcluster.api.models.update_cluster_response_content import UpdateClusterResponseContent
from pcluster.api.models.update_compute_fleet_request_content import UpdateComputeFleetRequestContent
from pcluster.api.models.update_compute_fleet_response_content import UpdateComputeFleetResponseContent
from pcluster.api.models.update_error import UpdateError
from pcluster.api.models.validation_level import ValidationLevel

==> aws-parallelcluster-3.6.0.tar.gz: aws-parallelcluster-3.6.0/src/pcluster/api/models/__init__.py <==
# Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
# with the License. A copy of the License is located at http://aws.amazon.com/apache2.0/
# or in the "LICENSE.txt" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
# OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions and
# limitations under the License.

# pylint: disable=R0801

# flake8: noqa


# import models into model package
from pcluster.api.models.ami_info import AmiInfo
from pcluster.api.models.bad_request_exception_response_content import BadRequestExceptionResponseContent
from pcluster.api.models.build_image_bad_request_exception_response_content import (
    BuildImageBadRequestExceptionResponseContent,
)
from pcluster.api.models.build_image_request_content import BuildImageRequestContent
from pcluster.api.models.build_image_response_content import BuildImageResponseContent
from pcluster.api.models.change import Change
from pcluster.api.models.cloud_formation_stack_status import CloudFormationStackStatus
from pcluster.api.models.cluster_configuration_structure import ClusterConfigurationStructure
from pcluster.api.models.cluster_info_summary import ClusterInfoSummary
from pcluster.api.models.cluster_instance import ClusterInstance
from pcluster.api.models.cluster_status import ClusterStatus
from pcluster.api.models.cluster_status_filtering_option import ClusterStatusFilteringOption
from pcluster.api.models.compute_fleet_status import ComputeFleetStatus
from pcluster.api.models.config_validation_message import ConfigValidationMessage
from pcluster.api.models.conflict_exception_response_content import ConflictExceptionResponseContent
from pcluster.api.models.create_cluster_bad_request_exception_response_content import (
    CreateClusterBadRequestExceptionResponseContent,
)
from pcluster.api.models.create_cluster_request_content import CreateClusterRequestContent
from pcluster.api.models.create_cluster_response_content import CreateClusterResponseContent
from pcluster.api.models.delete_cluster_response_content import DeleteClusterResponseContent
from pcluster.api.models.delete_image_response_content import DeleteImageResponseContent
from pcluster.api.models.describe_cluster_instances_response_content import DescribeClusterInstancesResponseContent
from pcluster.api.models.describe_cluster_response_content import DescribeClusterResponseContent
from pcluster.api.models.describe_compute_fleet_response_content import DescribeComputeFleetResponseContent
from pcluster.api.models.describe_image_response_content import DescribeImageResponseContent
from pcluster.api.models.dryrun_operation_exception_response_content import DryrunOperationExceptionResponseContent
from pcluster.api.models.ec2_ami_info import Ec2AmiInfo
from pcluster.api.models.ec2_ami_info_summary import Ec2AmiInfoSummary
from pcluster.api.models.ec2_ami_state import Ec2AmiState
from pcluster.api.models.ec2_instance import EC2Instance
from pcluster.api.models.failure import Failure
from pcluster.api.models.get_cluster_log_events_response_content import GetClusterLogEventsResponseContent
from pcluster.api.models.get_cluster_stack_events_response_content import GetClusterStackEventsResponseContent
from pcluster.api.models.get_image_log_events_response_content import GetImageLogEventsResponseContent
from pcluster.api.models.get_image_stack_events_response_content import GetImageStackEventsResponseContent
from pcluster.api.models.image_build_status import ImageBuildStatus
from pcluster.api.models.image_builder_image_status import ImageBuilderImageStatus
from pcluster.api.models.image_configuration_structure import ImageConfigurationStructure
from pcluster.api.models.image_info_summary import ImageInfoSummary
from pcluster.api.models.image_status_filtering_option import ImageStatusFilteringOption
from pcluster.api.models.instance_state import InstanceState
from pcluster.api.models.internal_service_exception_response_content import InternalServiceExceptionResponseContent
from pcluster.api.models.limit_exceeded_exception_response_content import LimitExceededExceptionResponseContent
from pcluster.api.models.list_cluster_log_streams_response_content import ListClusterLogStreamsResponseContent
from pcluster.api.models.list_clusters_response_content import ListClustersResponseContent
from pcluster.api.models.list_image_log_streams_response_content import ListImageLogStreamsResponseContent
from pcluster.api.models.list_images_response_content import ListImagesResponseContent
from pcluster.api.models.list_official_images_response_content import ListOfficialImagesResponseContent
from pcluster.api.models.log_event import LogEvent
from pcluster.api.models.log_stream import LogStream
from pcluster.api.models.metadata import Metadata
from pcluster.api.models.node_type import NodeType
from pcluster.api.models.not_found_exception_response_content import NotFoundExceptionResponseContent
from pcluster.api.models.requested_compute_fleet_status import RequestedComputeFleetStatus
from pcluster.api.models.scheduler import Scheduler
from pcluster.api.models.stack_event import StackEvent
from pcluster.api.models.tag import Tag
from pcluster.api.models.unauthorized_client_error_response_content import UnauthorizedClientErrorResponseContent
from pcluster.api.models.update_cluster_bad_request_exception_response_content import (
    UpdateClusterBadRequestExceptionResponseContent,
)
from pcluster.api.models.update_cluster_request_content import UpdateClusterRequestContent
from pcluster.api.models.update_cluster_response_content import UpdateClusterResponseContent
from pcluster.api.models.update_compute_fleet_request_content import UpdateComputeFleetRequestContent
from pcluster.api.models.update_compute_fleet_response_content import UpdateComputeFleetResponseContent
from pcluster.api.models.update_error import UpdateError
from pcluster.api.models.validation_level import ValidationLevel
